# hydrogen-pfhx
Chemical engineering model of hydrogen plate-fin heat exchanger.

## Installation
pip install hydrogen-pfhx

## Usage
hydrogen-pfhx is used to model the cryogenic plate-fin heat exchanger used within hydrogen liquefaction plants.
Two examples are given below:

1. Run with a python IDE (e.g. visual studio)
   - see the [test file](https://github.com/fsr-uwa/hydrogen-pfhx/blob/main/tests/test_model.py)

2. A notebook using google colab 
   - [open the test notebook in colab](https://colab.research.google.com/github/fsr-uwa/hydrogen-pfhx/blob/main/tests/test_model.ipynb)
   - run the notebook: saving data will require approval for google drive usage.
